pub(super) struct PreAuthWebSocketPermit {
_global_permit: OwnedSemaphorePermit,
origin_permit: Option<OwnedSemaphorePermit>,
origin: Arc<str>,
origins: Arc<Mutex<HashMap<Arc<str>, OriginAdmission>>>,
per_origin_capacity: usize,
}Expand description
holds global and origin pre-auth capacity until authentication releases it or the upgraded socket is dropped
dropping the permit removes idle origin buckets after the last origin permit returns
Fields
_global_permit: OwnedSemaphorePermitorigin_permit: Option<OwnedSemaphorePermit>origin: Arc<str>origins: Arc<Mutex<HashMap<Arc<str>, OriginAdmission>>>per_origin_capacity: usizeTrait Implementations
Sourceimpl Debug for PreAuthWebSocketPermit
impl Debug for PreAuthWebSocketPermit